OC.L10N.register(
    "forms",
    {
    "Copy" : "Salin",
    "Shared with you" : "Shared with you",
    "Select groups" : "Pilih grup",
    "Cancel" : "Batal",
    "Options" : "Pilihan",
    "Delete" : "Hapus",
    "Other" : "Lainnya",
    "never" : "tidak pernah.",
    "Set expiration date" : "Atur tanggal kedaluwarsa",
    "Group" : "Grup",
    "Share link" : "Bagikan tautan",
    "Add link" : "Tambah tautan",
    "Copy to clipboard" : "Salin ke papan klip",
    "Copy embedding code" : "Salin kode penyemat",
    "View" : "Tampilan",
    "Edit" : "Sunting",
    "Share" : "Bagikan",
    "Description" : "Deskrisi",
    "Summary" : "Kesimpulan",
    "Download" : "Unduh",
    "Search" : "Cari",
    "Sharing" : "Berbagi",
    "Settings" : "Setelan",
    "Abort" : "Batal",
    "Clear" : "Bersihkan",
    "No recommendations. Start typing." : "Tidak ada saran. Mulai mengetik.",
    "Checkboxes" : "Kotak centang",
    "Date" : "Date",
    "Pick a date" : "Pilih tanggal",
    "Time" : "Waktu",
    "Pick a time" : "Pilih waktu",
    "Color" : "Warna",
    "Image" : "Gambar",
    "Text" : "Teks",
    "Phone number" : "Nomor telepon",
    "Email address" : "Alamat email",
    "Uploading …" : "Mengunggah …"
},
"nplurals=1; plural=0;");
